# MSS (Marine Systems Simulator)

The Marine Systems Simulator (MSS) is a Matlab and Simulink library for marine systems (www.mathworks.com). The m-files are compatible with the free software GNU Octave (www.octave.org). MSS includes models for ships, underwater vehicles, uncrewed surface vehicles, and floating structures. The library also contains guidance, navigation, and control (GNC) blocks for real-time simulation. The algorithms are described in:

    T. I. Fossen (2021). Handbook of Marine Craft Hydrodynamics and Motion Control. 2nd. Edition, Wiley. ISBN-13: 978-1119575054

The lecture notes https://wiley.fossen.biz serve as documentation for the toolbox. Please include the following reference when using the MSS libraries: 

    T. I. Fossen and T. Perez (2004). Marine Systems Simulator (MSS)
    URL: https://github.com/cybergalactic/MSS

 Installation
-
Download the MSS Directory:
1. Navigate to the GitHub MSS repository and click on the green "Code" button.
2. Select "Download ZIP" from the dropdown menu.
3. Unzip the file to a desired location on your computer once the download is complete.

Set Up MATLAB Path:
1. Open MATLAB.
2. From the MATLAB menu, choose "Set Path."
3. Select "Add with Subfolders" and navigate to the unzipped MSS directory. Alternatively, if you are already in the main directory (the top-level folder of the MSS) in MATLAB, you can set the path directly by executing the following command in the MATLAB command window:

       addpath(genpath(pwd))
       savepath

Later, you can update an existing path automatically, and remove dead links by using the command

    mssPath

To get started and find help on using the MSS, type the following command in the MATLAB command window:

    mssHelp

Marine craft models and time-series simulation templates (m-files) are located under the catalog:

    /MSS/VESSELS/                           Marine craft model library

and the m-files can be listed by typing

    help VESSELS                            Marine craft models and time-series simulation templates (m-files)

Examples and demo files are located under the catalogs: 

    /MSS/mssExamples/                       Textbook m-file examples (Fossen 2021)  
    /MSS/mssDemos/                          MSS m-file demos
    /MSS/SIMULINK/mssSimulinkDemos/         Simulink demos  
    /MSS/SIMULINK/mssWamitShipXTemplates/   Simulink templates for simulation of WAMIT and ShipX vessel and RAO data
    
The Simulink library is loaded by typing:

    mssSimulink  


 GNC Library
-

Basic libraries and system examples for GNC. The library contains:

- M-file functions (kinematics and kinetics) and examples for time-domain GNC applications.
- M-file library with vessel models, maneuvering trials, and dynamic simulation.
- User-editable m-files for simulating and controlling marine craft, including ships, semisubmersibles, autonomous underwater vehicles (AUVs), remotely operated vehicles (ROVs), and uncrewed surface vehicles (USVs).

 INS Library
 -
 Functions and scripts for time-domain inertial navigation systems (INS) using unit quaternions and Euler angles. The library contains:
- User-editable m-files for implementation of error-state Kalman filters (ESKF).
- M-file library with aided INS functions.

 Hydro Library
-

The toolbox reads output data files generated by hydrodynamic programs and processes the data for use in Matlab. MSS Hydrodynamics includes several example vessels. To build your model, you need a license for one of the following programs:

- 2D strip theory programs - ShipX (Veres) by SINTEF OCEAN AS
- 3D potential theory programs - WAMIT by WAMIT Inc.

The processed data can be used in the real-time simulation of marine vessels in 6 DOFs exposed to 1st- and 2nd-order wave loads (motion and force RAO transfer functions) using the Simulink templates located under /MSS/SIMULINK/mssWamitShipXTemplates/.

FDI Toolbox
-
This is a stand-alone toolbox for identifying radiation-force models and fluid-memory effects of marine structures such as marine craft and wave energy converters. Please include the following reference when you use the MSS FDI toolbox:
 
    T. Perez and T. I. Fossen (2009). A Matlab Tool for Parametric Identification of Radiation-Force Models of Ships and Offshore Structures. 
    Modeling, Identification and Control, MIC-30(1):1-15. DOI: https://doi.org/10.4173/mic.2009.1.1 
